Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(86)

Unified Diff: tests/corelib/list_set_range_test.dart

Issue 10989013: Change IllegalArgumentException to ArgumentError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Updated co19 test expectations. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/corelib/list_set_range_test.dart
diff --git a/tests/corelib/list_set_range_test.dart b/tests/corelib/list_set_range_test.dart
index ad004a380564be7567a2a5b998eb00c0eceb4c91..c37e950665e33ed3762c374c9d97c8e8d40a990d 100644
--- a/tests/corelib/list_set_range_test.dart
+++ b/tests/corelib/list_set_range_test.dart
@@ -65,12 +65,12 @@ void testNegativeIndices() {
expectIOORE(() { list.setRange(-1, 1, [1]); });
expectIOORE(() { list.setRange(0, 1, [1], -1); });
// A negative length throws an IllegalArgumentException.
Expect.throws(() { list.setRange(0, -1, [1]); },
- (e) => e is IllegalArgumentException);
+ (e) => e is ArgumentError);
Expect.throws(() { list.setRange(-1, -1, [1], -1); },
- (e) => e is IllegalArgumentException);
+ (e) => e is ArgumentError);
Expect.listEquals([1, 2], list);
// A zero length prevails, and does not throw an exception.
@@ -65,12 +65,12 @@ void testNegativeIndices() {
expectIOORE(() { list.setRange(-1, 1, [1]); });
expectIOORE(() { list.setRange(0, 1, [1], -1); });
- // A negative length throws an IllegalArgumentException.
+ // A negative length throws an ArgumentError.
Expect.throws(() { list.setRange(0, -1, [1]); },

Powered by Google App Engine
This is Rietveld 408576698